import React, { useEffect } from "react";
import { Switch, Route } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import { TooltipProvider } from "@/components/ui/tooltip";
import { ROUTES } from "@/lib/constants";
import { PerformanceMonitor } from "./lib/performance";
import AuthPage from "@/pages/auth-page";
import ReplitAuthLanding from "@/pages/replit-auth-landing";
import SelectRole from "@/pages/auth/select-role";
import ForgotPassword from "@/pages/auth/forgot-password";
import ResetPassword from "@/pages/auth/reset-password";
import { ReplitProtectedRoute } from "@/components/replit-protected-route";

import NotFound from "@/pages/not-found";
import PublicLayout from "@/components/layout/public-layout";
import Login from "@/pages/auth/login";
import LoginSuccess from "@/pages/auth/login-success";
import Register from "@/pages/auth/register";
import DirectorRegistration from "@/pages/auth/register-director";
import ClientRegistration from "@/pages/auth/register-client";
import ClientDashboard from "@/pages/client/dashboard";
import ClientProfile from "@/pages/client/profile";
import DirectorDiscovery from "@/pages/director/discovery";
import DirectorProfile from "@/pages/director/profile";
import DirectorAvailability from "@/pages/director/availability";
import ProfileWizardPage from "@/pages/director/profile-wizard";
import DirectorSettings from "@/pages/director/settings";
import DirectorShowcase from "@/pages/director-showcase";
import DirectorDashboardMain from "@/pages/director-dashboard";
import DirectorProjects from "@/pages/director/projects";
import DirectorQuestionnairePage from "@/pages/director-questionnaire-page";
import DirectorProfileEdit from "@/pages/director-profile-edit";
import Home from "@/pages/home";
import HowItWorks from "@/pages/how-it-works";
import Services from "./pages/services";
import Contact from "./pages/contact";
import Terms from "./pages/terms";
import PrivacyPolicy from "./pages/privacy-policy";
import AboutPage from "./pages/about";
import DirectorAgreement from "./pages/director-agreement";
import Pricing from "./pages/pricing";
import FaqPage from "./pages/faq";
import { TagsDemo } from "@/pages/tags-demo";
import { AuthProvider } from "@/lib/auth";
import ProjectsPage from "@/pages/projects";
import ProjectDetailsPage from "@/pages/project-details";
import CreateProjectPage from "@/pages/create-project";
import ProjectDirectorsPage from "@/pages/projects/[id]/directors";
import ClientProfileCreate from "@/pages/client-profile-create";
import CompaniesPage from "@/pages/companies";
import { FloatingAssistant } from "@/components/help/floating-assistant";
import { RoleBasedRedirect } from "@/components/role-based-redirect";

// Admin Pages
import AdminDashboardPage from "@/pages/admin/index";
import AdminProjectsPage from "@/pages/admin/projects";
import AdminUsersPage from "@/pages/admin/users";
import AdminTagsPage from "@/pages/admin/tags";
import AdminSettingsPage from "@/pages/admin/settings";
import AgreementDemo from "@/pages/demo/agreement-demo";
import DirectorAgreementsPage from "@/pages/admin/director-agreements";
import AgreementsPage from "@/pages/admin/agreements";
import AdminMusicAnalysis from "@/pages/admin/music-analysis";
import AdminMusicPersonality from "@/pages/admin/music-personality";
import ProjectEditPage from "@/pages/admin/project-edit";
import ProjectViewPage from "@/pages/admin/projects/[id]/view";
import ProjectMatchingPage from "@/pages/admin/projects/[id]/matching";
import AdminProjectReviewPage from "@/pages/admin/projects/review";
import AdminPendingProjectsPage from "@/pages/admin/projects/pending-review";
import AdminMatchingProjectsPage from "@/pages/admin/projects/matching";
import AdminMessagesPage from "@/pages/admin/messages";
import DirectorQuestionnaireAdminPage from "@/pages/admin/director-questionnaire-admin";
import ProjectCurationPage from "@/pages/admin/projects/[id]/curation";
import ProjectMatchAddAllPage from "@/pages/admin/projects/[id]/match-add-all";
import AdminProjectShortlistPage from "@/pages/admin/projects/[id]/shortlist";
import AdminProjectAvailabilityPage from "@/pages/admin/projects/[id]/availability";
import AdminAvailabilityCheckPage from "@/pages/admin/projects/availability";
import AdminProjectProspectsPage from "@/pages/admin/projects/[id]/prospects";
import AdminClientSelectionPage from "@/pages/admin/projects/[id]/client-selection";
import AdminFinalSelectionPage from "@/pages/admin/projects/[id]/final-selection";
import MessagesPage from "@/pages/messages";
import NotificationsPage from "@/pages/notifications";
import TeamDashboard from "@/pages/team-dashboard";
import SettingsPage from "@/pages/settings";
import { ProtectedRoute } from "./lib/protected-route";

function Router() {
  useEffect(() => {
    PerformanceMonitor.startMeasurement("App Initialization");
    
    // Clean up measurement after component mounts
    const cleanup = () => PerformanceMonitor.endMeasurement("App Initialization");
    setTimeout(cleanup, 0);
    
    return cleanup;
  }, []);

  return (
    <Switch>
      {/* Public routes with header and footer */}
      <Route path={ROUTES.HOME}>
        <PublicLayout
          title="Distinkt.co - Global Director Matchmaking Platform"
          description="Connect with top commercial directors worldwide. Distinkt.co matches clients with the perfect director for their creative projects through our AI-powered platform."
          keywords={['commercial directors', 'director matchmaking', 'creative projects', 'film directors', 'video production', 'AI matching', 'commercial production platform', 'director-brand matching service', 'production talent marketplace']}
        >
          <Home />
        </PublicLayout>
      </Route>
      <Route path={ROUTES.LOGIN}>
        <PublicLayout>
          <Login />
        </PublicLayout>
      </Route>
      <Route path="/login-success">
        <PublicLayout>
          <LoginSuccess />
        </PublicLayout>
      </Route>
      <Route path={ROUTES.REGISTER}>
        <PublicLayout>
          <Register />
        </PublicLayout>
      </Route>
      <Route path="/forgot-password">
        <PublicLayout>
          <ForgotPassword />
        </PublicLayout>
      </Route>
      <Route path="/reset-password">
        <PublicLayout>
          <ResetPassword />
        </PublicLayout>
      </Route>
      <Route path={ROUTES.REGISTER_DIRECTOR}>
        <PublicLayout>
          <DirectorRegistration />
        </PublicLayout>
      </Route>
      <Route path={ROUTES.REGISTER_CLIENT}>
        <PublicLayout>
          <ClientRegistration />
        </PublicLayout>
      </Route>
      <Route path="/d/:id">
        <PublicLayout>
          <DirectorShowcase />
        </PublicLayout>
      </Route>
      <Route path={ROUTES.HOW_IT_WORKS}>
        <PublicLayout
          title="How It Works | Distinkt.co"
          description="Learn how our AI-powered platform connects clients with the perfect commercial directors for their projects. Discover our streamlined process for director matching."
          keywords={['how it works', 'director matching process', 'creative matchmaking', 'find commercial directors', 'AI platform']}
        >
          <HowItWorks />
        </PublicLayout>
      </Route>
      <Route path={ROUTES.SERVICES}>
        <PublicLayout>
          <Services />
        </PublicLayout>
      </Route>
      <Route path={ROUTES.CONTACT}>
        <PublicLayout
          title="Contact Us | Distinkt.co"
          description="Get in touch with the Distinkt.co team. Whether you have questions about our director matchmaking platform, need support, or want to join our network."
          keywords={['contact distinkt', 'director platform support', 'commercial director assistance', 'creative matchmaking help']}
        >
          <Contact />
        </PublicLayout>
      </Route>
      <Route path={ROUTES.ABOUT}>
        <PublicLayout
          title="About Distinkt.co | Global Director Matchmaking"
          description="Learn about Distinkt.co, the AI-powered platform connecting clients with commercial directors worldwide. Discover our mission, values, and the team behind our innovative matchmaking service."
          keywords={['about distinkt', 'director matchmaking company', 'creative industry platform', 'commercial directors network']}
        >
          <AboutPage />
        </PublicLayout>
      </Route>
      <Route path={ROUTES.FAQ}>
        <PublicLayout>
          <FaqPage />
        </PublicLayout>
      </Route>
      <Route path={ROUTES.PRICING}>
        <PublicLayout>
          <Pricing />
        </PublicLayout>
      </Route>
      <Route path={ROUTES.TERMS}>
        <PublicLayout>
          <Terms />
        </PublicLayout>
      </Route>
      <Route path={ROUTES.PRIVACY_POLICY}>
        <PublicLayout>
          <PrivacyPolicy />
        </PublicLayout>
      </Route>
      <Route path={ROUTES.DIRECTOR_AGREEMENT}>
        <PublicLayout>
          <DirectorAgreement />
        </PublicLayout>
      </Route>
      <Route path="/tags-demo">
        <PublicLayout>
          <TagsDemo />
        </PublicLayout>
      </Route>
      
      <Route path="/demo/agreement">
        <PublicLayout>
          <AgreementDemo />
        </PublicLayout>
      </Route>
      
      <Route path="/auth/select-role">
        <PublicLayout>
          <SelectRole />
        </PublicLayout>
      </Route>
      
      <Route path="/auth/replit-callback">
        <PublicLayout>
          <ReplitAuthLanding />
        </PublicLayout>
      </Route>
      
      {/* Protected routes with their own navigation */}
      {/* Role-based dashboard redirect */}
      <Route path={ROUTES.DASHBOARD}>
        <RoleBasedRedirect />
      </Route>
      <ProtectedRoute path={ROUTES.CLIENT_DASHBOARD} component={ClientDashboard} />
      <ProtectedRoute path="/client" component={ClientDashboard} />
      <ProtectedRoute path={ROUTES.DIRECTOR_DASHBOARD} component={DirectorDashboardMain} />
      <ProtectedRoute path="/director/dashboard" component={DirectorDashboardMain} />
      <ProtectedRoute path="/director/projects" component={DirectorProjects} directorOnly={true} />
      <ProtectedRoute path="/director/profile" component={DirectorProfile} directorOnly={true} />
      <ProtectedRoute path="/director/notifications" component={NotificationsPage} directorOnly={true} />
      <ProtectedRoute path="/director/wizard" component={ProfileWizardPage} directorOnly={true} />
      <ProtectedRoute path="/directors/:id" component={DirectorProfile} />
      <ProtectedRoute path="/directors/:id/availability" component={DirectorAvailability} />
      <ProtectedRoute path="/directors/:id/wizard" component={ProfileWizardPage} />
      <ProtectedRoute path="/directors/wizard" component={ProfileWizardPage} />
      <ProtectedRoute path="/director/settings" component={DirectorSettings} directorOnly={true} />
      
      {/* Admin Routes - protected and admin only */}
      <ProtectedRoute path={ROUTES.ADMIN} component={AdminDashboardPage} adminOnly={true} />
      <ProtectedRoute path={ROUTES.ADMIN_USERS} component={AdminUsersPage} adminOnly={true} />
      <ProtectedRoute path={ROUTES.ADMIN_TAGS} component={AdminTagsPage} adminOnly={true} />
      <ProtectedRoute path={ROUTES.ADMIN_SETTINGS} component={AdminSettingsPage} adminOnly={true} />
      <ProtectedRoute path="/admin/music-analysis" component={AdminMusicAnalysis} adminOnly={true} />
      <ProtectedRoute path="/admin/music-personality" component={AdminMusicPersonality} adminOnly={true} />
      <ProtectedRoute path={ROUTES.ADMIN_DIRECTOR_AGREEMENTS} component={DirectorAgreementsPage} adminOnly={true} />
      <ProtectedRoute path={ROUTES.ADMIN_AGREEMENTS} component={AgreementsPage} adminOnly={true} />
      {/* E-signature debug page removed */}
      <ProtectedRoute path="/admin/projects/review" component={AdminProjectReviewPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/pending" component={AdminPendingProjectsPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/matching" component={AdminMatchingProjectsPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/availability" component={AdminAvailabilityCheckPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/new" component={ProjectEditPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/:id/availability" component={AdminProjectAvailabilityPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/:id/match-add-all" component={ProjectMatchAddAllPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/:id/matching" component={ProjectMatchingPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/:id/curation" component={ProjectCurationPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/:id/prospects" component={AdminProjectProspectsPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/:id/client-selection" component={AdminClientSelectionPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/:id/final-selection" component={AdminFinalSelectionPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/:id/shortlist" component={AdminProjectShortlistPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/:id/view" component={ProjectViewPage} adminOnly={true} />
      <ProtectedRoute path="/admin/projects/:id" component={ProjectEditPage} adminOnly={true} />
      <ProtectedRoute path={ROUTES.ADMIN_PROJECTS} component={AdminProjectsPage} adminOnly={true} />
      <ProtectedRoute path={ROUTES.ADMIN_MESSAGES} component={AdminMessagesPage} adminOnly={true} />
      <ProtectedRoute path="/admin/director-questionnaire/:id?" component={DirectorQuestionnaireAdminPage} adminOnly={true} />
      
      {/* Director Routes - protected and director only */}
      <ProtectedRoute path={ROUTES.DIRECTOR_QUESTIONNAIRE} component={DirectorQuestionnairePage} directorOnly={true} />
      <ProtectedRoute path={ROUTES.DIRECTOR_PROFILE_EDIT} component={DirectorProfileEdit} directorOnly={true} />
      <ProtectedRoute path="/directors/:id/edit" component={DirectorProfileEdit} directorOnly={true} />
      
      {/* User messaging */}
      <ProtectedRoute path={ROUTES.MESSAGES} component={MessagesPage} />
      
      {/* User settings */}
      <ProtectedRoute path="/settings" component={SettingsPage} />
      
      {/* Team collaboration */}
      <ProtectedRoute path={ROUTES.TEAM_DASHBOARD} component={TeamDashboard} />
      
      {/* Client profile */}
      <ProtectedRoute path={ROUTES.CLIENT_PROFILE_CREATE} component={ClientProfileCreate} />
      <ProtectedRoute path={ROUTES.CLIENT_PROFILE} component={ClientProfile} />
      
      {/* Projects management */}
      <ProtectedRoute path="/projects" component={ProjectsPage} requiresClientProfile={true} />
      <ProtectedRoute path="/projects/new" component={CreateProjectPage} requiresClientProfile={true} />
      <ProtectedRoute path="/projects/:id/edit" component={CreateProjectPage} requiresClientProfile={true} />
      <ProtectedRoute path="/projects/:id/directors" component={ProjectDirectorsPage} requiresClientProfile={true} />
      <ProtectedRoute path="/projects/:id" component={ProjectDetailsPage} requiresClientProfile={true} />
      
      {/* Companies management */}
      <ProtectedRoute path={ROUTES.COMPANIES} component={CompaniesPage} />
      
      {/* Demo Pages */}
      <Route path="/demo/agreement">
        <PublicLayout>
          <React.Suspense fallback={<div>Loading...</div>}>
            {React.createElement(React.lazy(() => import('./pages/demo/agreement-demo')))}
          </React.Suspense>
        </PublicLayout>
      </Route>
      
      {/* Replit Auth Routes */}
      <Route path="/auth">
        <AuthPage />
      </Route>
      
      <Route path="/replit-auth">
        <ReplitAuthLanding />
      </Route>
      
      {/* Replit Auth Test Route */}
      <ReplitProtectedRoute path="/replit-protected" component={() => (
        <div className="p-8">
          <h1 className="text-3xl font-bold mb-4">Protected Page</h1>
          <p className="mb-4">This page is protected by Replit Authentication.</p>
          <p>If you can see this, you are successfully authenticated!</p>
        </div>
      )} />
      
      {/* Not Found Page */}
      <Route>
        <PublicLayout>
          <NotFound />
        </PublicLayout>
      </Route>
    </Switch>
  );
}

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <AuthProvider>
        <TooltipProvider>
          <Toaster />
          <div className="flex flex-col min-h-screen">
            <Router />
            <FloatingAssistant />
          </div>
        </TooltipProvider>
      </AuthProvider>
    </QueryClientProvider>
  );
}

export default App;
